@@ -12,13 +12,15 @@ use English qw/ -no_match_vars /;
 use Time::Piece;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
+use utf8;
 
-our $VERSION  = 0.96008;
+our $VERSION  = 0.96009;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
 
 sub run {
+    my ($self) = @_;
     %option = (
         period => 'day',
     );
@@ -26,6 +28,9 @@ sub run {
         \%option,
         'remote|r',
         'all|a',
+        'fmt|format|f=s',
+        'changes|c',
+        'min|min-commits|M=i',
         'date|d=s',
         'period|p=s',
         'merges|m!',
@@ -63,15 +68,49 @@ sub run {
         }
     }
 
-    print map {sprintf "% 4d $_\n", $users{$_}}
-        reverse sort {$users{$a} <=> $users{$b}}
-        map { $users{$_} = scalar keys %{$users{$_}}; $_ }
-        keys %users;
-    print "Total commits = $commits\n";
+    for my $user (keys %users) {
+        my $commits = $users{$user};
+        $users{$user} = {
+            commit_count => scalar keys %{ $users{$user} },
+            $option{commits} ? (commits => [keys %{ $users{$user} }]) : (),
+        }
+    }
+
+    my $fmt = 'fmt_' . ($option{fmt} || 'table');
+    if ($self->can($fmt)) {
+        $self->$fmt(\%users, $commits);
+    }
 
     return;
 }
 
+sub fmt_table {
+    my ($self, $users, $total) = @_;
+
+    print map {sprintf "% 5d $_\n", $users->{$_}{commit_count}}
+        reverse sort {$users->{$a}{commit_count} <=> $users->{$b}{commit_count}}
+        grep { $users->{$_}{commit_count} >= ($option{min} || 0) }
+        keys %$users;
+    print "Total commits = $total\n";
+
+    return;
+}
+
+sub fmt_json {
+    my ($self, $users, $total) = @_;
+    require JSON;
+
+    print JSON::encode_json({ total => $total, users => $users });
+}
+
+sub fmt_perl {
+    my ($self, $users, $total) = @_;
+    require Data::Dumper;
+
+    local $Data::Dumper::Indent = 1;
+    print Data::Dumper::Dumper({ total => $total, users => $users });
+}
+
 1;
 
 __DATA__
@@ -82,7 +121,7 @@ git-committers - Stats on the number of commits by committer
 
 =head1 VERSION
 
-This documentation refers to git-committers version 0.96008
+This documentation refers to git-committers version 0.96009
 
 =head1 SYNOPSIS
 
@@ -93,6 +132,12 @@ This documentation refers to git-committers version 0.96008
   -a --all      Committers to any branch (remote or local)
   -d --date=YYYY-MM-DD
                 Commits since this date
+  -f --format[=](table|json|csv)
+                Change how the data is presented
+                   - table : shows the data in a simple table
+                   - json  : returns the raw data as a json object
+                   - perl  : Dump the data structure
+                   - csv   : Like table but as a csv
   -p --period=[day|week|month|year]
                 If --date is not specified this works out the date for the
                 last day/week/month/year
@@ -116,6 +161,18 @@ to the git repository.
 
 Executes the git workflow command
 
+=head2 C<fmt_table ()>
+
+Output a table
+
+=head2 C<fmt_json ()>
+
+Output JSON
+
+=head2 C<fmt_perl ()>
+
+Output a Perl object
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
